{% extends "admin/change_form.html" %}
{% block content %}
<div id="content-main">
  {% if step == 'upload' %}
  <form action="./" enctype="multipart/form-data" method="post">
    {% csrf_token %}
    <fieldset class="grp-module ">
      <div class="grp-row grp-cells-1 title ">
        <div class="l-2c-fluid l-d-4">
          <div class="c-1">
            <label class="required" for="id_files">Files</label>
          </div>
          <div class="c-2">
            <input class="vTextField" type="file" multiple="multiple" name="files" id="id_files">
          </div>
        </div>
      </div>
      <div class="grp-row grp-cells-1 title ">
        <div class="l-2c-fluid l-d-4">
          <div class="c-1">
            
          </div>
          <div class="c-2">
            <input type="submit" value="Upload" class="grp-button grp-default" name="upload">
          </div>
        </div>
      </div>
    </fieldset>
  </form>
  {% elif step == 'titles' %}
  titles
  {% endif %}
</div>
{% endblock %}
